==> item-descriptions-2.5.6%2B1.21.1-fabric-sources.jar: cc/cassian/item_descriptions/client/limelight/DescriptionsExtension.java <==
package cc.cassian.item_descriptions.client.limelight;

//? if fabric {
//? if 1.21.1 || 1.21.5 {
import cc.cassian.item_descriptions.client.helpers.ModHelpers;
import io.wispforest.limelight.api.builtin.bangs.BangDefinition;
import io.wispforest.limelight.api.builtin.bangs.BangsProvider;
import io.wispforest.limelight.api.entry.ResultEntry;
import io.wispforest.limelight.api.entry.ResultGatherContext;
import io.wispforest.limelight.api.extension.LimelightExtension;
import java.util.List;
import java.util.Objects;
import java.util.function.Consumer;
import net.minecraft.class_2561;
import net.minecraft.class_2960;

import static cc.cassian.item_descriptions.client.ModClient.MOD_ID;

public class DescriptionsExtension implements LimelightExtension, BangsProvider {
    public static final class_2960 ID = ModHelpers.of("item_descriptions");
    public static final DescriptionsExtension INSTANCE = new DescriptionsExtension();

    @Override
    public class_2960 id() {
        return ID;
    }

    @Override
    public List<BangDefinition> bangs() {
        return List.of(new BangDefinition(
                "descriptions",
                class_2561.method_43471("limelightExtension.item-descriptions.item_descriptions"),
                (ctx, entryConsumer) -> entryConsumer.accept(new DescriptionsResultEntry(ctx.searchText()))
        ));
    }

    @Override
    public void gatherEntries(ResultGatherContext ctx, Consumer<ResultEntry> entryConsumer) {
        var resultEntry = new DescriptionsResultEntry((ctx.searchText()));
        if (!Objects.requireNonNull(resultEntry.text().getString()).isEmpty()) {
            entryConsumer.accept(new DescriptionsResultEntry(ctx.searchText()));
        }
    }
}
//?}
//?}

==> item-descriptions-2.5.7%2B1.21.11-rc3-fabric-sources.jar: cc/cassian/item_descriptions/client/limelight/DescriptionsExtension.java <==
package cc.cassian.item_descriptions.client.limelight;

//? if fabric {
//? if 1.21.1 || 1.21.5 {
/*import cc.cassian.item_descriptions.client.helpers.ModHelpers;
import io.wispforest.limelight.api.builtin.bangs.BangDefinition;
import io.wispforest.limelight.api.builtin.bangs.BangsProvider;
import io.wispforest.limelight.api.entry.ResultEntry;
import io.wispforest.limelight.api.entry.ResultGatherContext;
import io.wispforest.limelight.api.extension.LimelightExtension;
import net.minecraft.network.chat.Component;
import net.minecraft.resources.Identifier;

import java.util.List;
import java.util.Objects;
import java.util.function.Consumer;

import static cc.cassian.item_descriptions.client.ModClient.MOD_ID;

public class DescriptionsExtension implements LimelightExtension, BangsProvider {
    public static final Identifier ID = ModHelpers.of("item_descriptions");
    public static final DescriptionsExtension INSTANCE = new DescriptionsExtension();

    @Override
    public Identifier id() {
        return ID;
    }

    @Override
    public List<BangDefinition> bangs() {
        return List.of(new BangDefinition(
                "descriptions",
                Component.translatable("limelightExtension.item-descriptions.item_descriptions"),
                (ctx, entryConsumer) -> entryConsumer.accept(new DescriptionsResultEntry(ctx.searchText()))
        ));
    }

    @Override
    public void gatherEntries(ResultGatherContext ctx, Consumer<ResultEntry> entryConsumer) {
        var resultEntry = new DescriptionsResultEntry((ctx.searchText()));
        if (!Objects.requireNonNull(resultEntry.text().getString()).isEmpty()) {
            entryConsumer.accept(new DescriptionsResultEntry(ctx.searchText()));
        }
    }
}
*///?}
//?}
